package docar.util.profile;

import java.io.PrintStream;
import java.util.Iterator;
import java.util.Map.Entry;

import docar.util.profile.Profiler.Accumulation;

/**
 * 성능 측정 결과를 출력하는 클래스
 * 
 * @author "Sunny Kwak"
 */
public class Report {
	public static void report(PrintStream printStream) {
		Iterator<Entry<String, Accumulation>> iterator = Profiler.getInstance()
				.iterator();

		while (iterator.hasNext()) {
			Entry<String, Accumulation> entry = iterator.next();
			String functionName = entry.getKey();
			long callNumber = entry.getValue().getCallNumber();
			long runningTime = entry.getValue().getAccumulatedRunningTime();

			// 기능 명칭 및 호출 횟수 출력.
			printStream.format("Function name : %s, Call number : %,d\n",
					functionName, callNumber);

			// 총 수행 시간 출력.
			long runningTimeAsSeconds = runningTime / 1000;
			long runningTimeAsMins = runningTimeAsSeconds / 60;
			printStream.format(
					"Total running time : %,d ms, %,d seconds, %,d min \n",
					runningTime, runningTimeAsSeconds, runningTimeAsMins);

			// 평균 수행 시간 출력.
			long averageTime = runningTime / callNumber;
			long averageTimeAsSeconds = runningTime / callNumber / 1000;
			long averageTimeAsMins = averageTimeAsSeconds / 60;
			printStream.format(
					"Average running time : %,d ms , %,d seconds, %,d min\n\n",
					averageTime, averageTimeAsSeconds, averageTimeAsMins);
		}
	}
}
