package docar.util.profile;

/**
 * 특정 기능(메소드, 클래스)의 수행 시간을 측정하는 클래스.
 *
 * @author "Sunny Kwak"
 */
public class StopWatch {
	// 기능 명칭
	private String functionName;
	// 기능의 시작 시간
	private long startTime;
	// 기능의 종료 시간 (단위 : 밀리 초, millisecond)
	private long endTime;
	
	/**
	 * 인스턴스 생성 시에 '시작 시간'을 기록한다.
	 * 
	 * @param functionName 기능 명칭
	 */
	public StopWatch(String functionName) {
		this.functionName = functionName;
		this.startTime = System.currentTimeMillis();
	}
	
	/**
	 * 기능의 1회 수행 시간을 기록한다.
	 * 
	 * @return StopWatch 인스턴스
	 */
	public StopWatch stop() {
		endTime = System.currentTimeMillis();
		return this;
	}
	
	/**
	 * @return 기능 명칭
	 */
	public String getFunctionName() {
		return functionName;
	}
	
	/**
	 * @return 수행 시간 (단위 : 밀리 초)
	 */
	public long getEllapsedTime() {
		return endTime - startTime;
	}
}
